
# Neqs

Newton-based nonlinear equation solvers


## Project URLs

Homepage: [`https://github.com/iris-solutions-team/neqs`](https://github.com/iris-solutions-team/neqs)

Documentation: [`https://iris-solutions-team.github.io/neqs-pages`](https://iris-solutions-team.github.io/neqs-pages)

Bug Tracker: [`https://github.com/iris-solutions-team/neqs/issues`](https://github.com/iris-solutions-team/neqs/issues)


